Bookshelf
=========

.. include:: ../../README.rst
    :start-after: sec-begin-long-description
    :end-before: sec-end-long-description



.. toctree::
  :maxdepth: 2
  :caption: Contents:

  installation
  usage
  configuration
  reference/index
  development/index



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
